import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = 'https://gist.githubusercontent.com/Ramch16/057790908ed8a17561a4a4138f431e85/raw/7edbdb7d339d8080f664b09e700c1434997f006b/Iris_ICE7.csv'
// Function to fetch data from the URI
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};
const parseRow = (d) => {
  d.SepalLengthCm = +d.SepalLengthCm;
  d.SepalWidthCm = +d.SepalWidthCm;
  d.PetalLengthCm = +d.PetalLengthCm;
  d.PetalWidthCm = +d.PetalWidthCm;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height-20)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.PetalWidthCm)
    .yValue((d) => d.SepalLengthCm)
  
    .margin({
      top: 20,
      right: 20,
      bottom: 40,
      left: 120,
    })
    .radius(5);

  svg.call(plot);

  const columns = [
    'PetalWidthCm',
    'SepalWidthCm',
    'PetalLengthCm',
    'SepalLengthCm',
  ];
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 1000);
   svg.append('text')
      .attr('class','axis-label')
      .attr('x',innerWidth/2.0)
      .attr('y',50)
      .style('font-size', '30px')
      .text("Scatter Plot")

      svg.append('text')
      .attr('class', 'axis-label')
      .attr('x', width / 2)
      .attr('y', height - 10)
      .style('font-size', '20px')
      .style('text-anchor', 'middle')
      .text('Petal_Width ');

  svg.append('text')
      .attr('class', 'axis-label')
      .style('font-size', '20px')
      .style('text-anchor', 'middle')
      .attr('y', 50)
      .attr('x',-240)
      .text('Sepal_Length')
      .attr("transform", "rotate(-90)");

};
main();



